@@ -1,7 +1,10 @@
 #!/usr/bin/env python
 import itertools
 import re
+from contextlib import contextmanager
+from gettext import NullTranslations
 from typing import (
+    Any,
     Callable,
     Dict,
     Iterable,
@@ -11,12 +14,13 @@ from typing import (
     Set,
     Tuple,
     Union,
+    cast,
     overload,
 )
 
 from django.utils.encoding import force_str
-from django.utils.translation import get_language, override
-from typing_extensions import Literal
+from django.utils.translation import _trans, override
+from typing_extensions import Literal, TypedDict
 
 from django_countries.conf import settings
 
@@ -28,7 +32,7 @@ try:
     collator = pyuca.Collator()
 
     # Use UCA sorting if it's available.
-    def sort_key(item):
+    def sort_key(item: Tuple[str, str]) -> Any:
         return collator.sort_key(item[1])
 
 except ImportError:
@@ -36,7 +40,7 @@ except ImportError:
     import unicodedata
 
     # Cheap and dirty method to sort against ASCII characters only.
-    def sort_key(item):
+    def sort_key(item: Tuple[str, str]) -> Any:
         return (
             unicodedata.normalize("NFKD", item[1])
             .encode("ascii", "ignore")
@@ -44,6 +48,31 @@ except ImportError:
         )
 
 
+class EmptyFallbackTranslator(NullTranslations):
+    def gettext(self, message: str) -> str:
+        return ""
+
+
+@contextmanager
+def no_translation_fallback():
+    catalog = _trans.catalog()
+    original_fallback = catalog._fallback
+    catalog._fallback = EmptyFallbackTranslator()
+    try:
+        yield
+    finally:
+        catalog._fallback = original_fallback
+
+
+class ComplexCountryName(TypedDict):
+    name: str
+    names: List[str]
+    alpha3: str
+    numeric: int
+    ioc_code: str
+
+
+CountryName = Union[str, ComplexCountryName]
 CountryCode = Union[str, int, None]
 
 
@@ -56,7 +85,7 @@ class CountryTuple(NamedTuple):
     code: str
     name: str
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         """
         Display the repr as a standard tuple for better backwards
         compatibility with outputting this in a template.
@@ -72,7 +101,7 @@ class Countries(CountriesBase):
     the country ``code`` and ``name``), sorted by name.
     """
 
-    _countries: Dict[str, Union[str, Dict]]
+    _countries: Dict[str, CountryName]
     _alt_codes: Dict[str, AltCodes]
 
     def get_option(self, option: str):
@@ -86,7 +115,7 @@ class Countries(CountriesBase):
         return getattr(settings, f"COUNTRIES_{option.upper()}")
 
     @property
-    def countries(self) -> Dict[str, Union[str, dict]]:
+    def countries(self) -> Dict[str, CountryName]:
         """
         Return the a dictionary of countries, modified by any overriding
         options.
@@ -126,14 +155,19 @@ class Countries(CountriesBase):
                     for code, name in self.COMMON_NAMES.items():
                         if code in self._countries:
                             self._countries[code] = name
-                override: Dict[str, Union[str, dict]] = self.get_option("override")
+                override: Dict[str, Union[CountryName, None]] = self.get_option(
+                    "override"
+                )
                 if override:
-                    self._countries.update(override)
-                    self._countries = dict(
-                        (code, name)
-                        for code, name in self._countries.items()
-                        if name is not None
+                    _countries = cast(
+                        Dict[str, Union[CountryName, None]], self._countries.copy()
                     )
+                    _countries.update(override)
+                    self._countries = {
+                        code: name
+                        for code, name in _countries.items()
+                        if name is not None
+                    }
 
                 if self.get_option("common_names"):
                     for code in self.COMMON_NAMES:
@@ -230,7 +264,7 @@ class Countries(CountriesBase):
         for name in names:
             yield self.translate_pair(code, name)
 
-    def translate_pair(self, code: str, name: Union[str, Dict] = None):
+    def translate_pair(self, code: str, name: Optional[CountryName] = None):
         """
         Force a country to the current activated translation.
 
@@ -240,31 +274,29 @@ class Countries(CountriesBase):
             name = self.countries[code]
         if isinstance(name, dict):
             if "names" in name:
-                country_name: str = name["names"][0]
                 fallback_names: List[str] = name["names"][1:]
+                name: str = name["names"][0]
             else:
-                country_name = name["name"]
                 fallback_names = []
+                name = name["name"]
         else:
-            country_name = name
             fallback_names = self.shadowed_names.get(code, [])
-        language = get_language()
-        if language and language.split("-")[0] != "en" and fallback_names:
-            # Check if there's an older translation available if there's no
-            # translation for the newest name.
-            with override("en"):
-                source_name = force_str(country_name)
-            country_name = force_str(country_name)
-            if country_name == source_name:
-                for fallback_name in fallback_names:
-                    with override("en"):
-                        source_fallback_name = force_str(fallback_name)
-                    fallback_name = force_str(fallback_name)
-                    if fallback_name != source_fallback_name:
-                        country_name = fallback_name
-                        break
+        if fallback_names:
+            with no_translation_fallback():
+                country_name = force_str(name)
+                # Check if there's an older translation available if there's no
+                # translation for the newest name.
+                if not country_name:
+                    for fallback_name in fallback_names:
+                        fallback_name = force_str(fallback_name)
+                        if fallback_name:
+                            country_name = fallback_name
+                            break
+            if not country_name:
+                # Use the translation's fallback country name.
+                country_name = force_str(name)
         else:
-            country_name = force_str(country_name)
+            country_name = force_str(name)
         return CountryTuple(code, country_name)
 
     def __iter__(self):
@@ -293,8 +325,7 @@ class Countries(CountriesBase):
         if self.get_option("first_sort"):
             countries_first = sorted(countries_first, key=sort_key)
 
-        for item in countries_first:
-            yield item
+        yield from countries_first
 
         if self.countries_first:
             first_break = self.get_option("first_break")
@@ -310,8 +341,7 @@ class Countries(CountriesBase):
         )
 
         # Return sorted country list.
-        for item in sorted(countries, key=sort_key):
-            yield item
+        yield from sorted(countries, key=sort_key)
 
     def alpha2(self, code: CountryCode) -> str:
         """
@@ -447,7 +477,7 @@ class Countries(CountriesBase):
             return code_list
         return ""
 
-    def alpha3(self, code: CountryCode):
+    def alpha3(self, code: CountryCode) -> str:
         """
         Return the ISO 3166-1 three letter country code matching the provided
         country code.
@@ -461,7 +491,19 @@ class Countries(CountriesBase):
             alpha3 = ""
         return alpha3 or ""
 
-    def numeric(self, code: Union[str, int, None], padded=False):
+    @overload
+    def numeric(
+        self, code: Union[str, int, None], padded: Literal[False] = False
+    ) -> Optional[int]:
+        ...
+
+    @overload
+    def numeric(
+        self, code: Union[str, int, None], padded: Literal[True]
+    ) -> Optional[str]:
+        ...
+
+    def numeric(self, code: Union[str, int, None], padded: bool = False):
         """
         Return the ISO 3166-1 numeric country code matching the provided
         country code.
