@@ -1,5 +1,5 @@
 import re
-from typing import Any, Iterable, Tuple, Type, Union, cast
+from typing import Any, Iterable, Optional, Tuple, Type, Union, cast
 from urllib import parse as urlparse
 
 import pkg_resources
@@ -15,10 +15,10 @@ from django.utils.html import escape as escape_html
 from django_countries import Countries, countries, filters, ioc_data, widgets
 from django_countries.conf import settings
 
-EXTENSIONS = dict(
-    (ep.name, ep.load())
+EXTENSIONS = {
+    ep.name: ep.load()
     for ep in pkg_resources.iter_entry_points("django_countries.Country")
-)
+}
 
 
 class TemporaryEscape:
@@ -39,7 +39,13 @@ class TemporaryEscape:
 
 
 class Country:
-    def __init__(self, code, flag_url=None, str_attr="code", custom_countries=None):
+    def __init__(
+        self,
+        code: str,
+        flag_url: Optional[str] = None,
+        str_attr: str = "code",
+        custom_countries: Optional[Countries] = None,
+    ):
         self.flag_url = flag_url
         self._escape = False
         self._str_attr = str_attr
@@ -69,8 +75,7 @@ class Country:
             args.append(f"flag_url={self.flag_url!r}")
         if self._str_attr != "code":
             args.append(f"str_attr={self._str_attr!r}")
-        args = ", ".join(args)
-        return f"{self.__class__.__name__}({args})"
+        return f"{self.__class__.__name__}({', '.join(args)})"
 
     def __bool__(self):
         return bool(self.code)
@@ -86,29 +91,27 @@ class Country:
     def escape(self):
         return TemporaryEscape(self)
 
-    def maybe_escape(self, text):
-        if not self.escape:
-            return text
-        return escape_html(text)
+    def maybe_escape(self, text) -> str:
+        return escape_html(text) if self.escape else text
 
     @property
-    def name(self):
+    def name(self) -> str:
         return self.maybe_escape(self.countries.name(self.code))
 
     @property
-    def alpha3(self):
+    def alpha3(self) -> str:
         return self.countries.alpha3(self.code)
 
     @property
-    def numeric(self):
+    def numeric(self) -> Optional[int]:
         return self.countries.numeric(self.code)
 
     @property
-    def numeric_padded(self):
+    def numeric_padded(self) -> Optional[str]:
         return self.countries.numeric(self.code, padded=True)
 
     @property
-    def flag(self):
+    def flag(self) -> str:
         if not self.code:
             return ""
         flag_url = self.flag_url
@@ -121,7 +124,7 @@ class Country:
         return self.maybe_escape(url)
 
     @property
-    def flag_css(self):
+    def flag_css(self) -> str:
         """
         Output the css classes needed to display an HTML element as a flag
         sprite.
@@ -133,7 +136,7 @@ class Country:
         """
         if not self.code:
             return ""
-        x, y = self.code.lower()
+        x, y = list(self.code.lower())
         return f"flag-sprite flag-{x} flag-_{y}"
 
     @property
@@ -257,7 +260,7 @@ class CountryField(CharField):
 
     descriptor_class = CountryDescriptor
 
-    def __init__(self, *args, **kwargs):
+    def __init__(self, *args: Any, **kwargs: Any):
         countries_class: Type[Countries] = kwargs.pop("countries", None)
         self.countries = countries_class() if countries_class else countries
         self.countries_flag_url = kwargs.pop("countries_flag_url", None)
@@ -320,10 +323,7 @@ class CountryField(CharField):
         "Returns field's value prepared for saving into a database."
         value = self.get_clean_value(value)
         if self.multiple:
-            if value:
-                value = ",".join(value)
-            else:
-                value = ""
+            value = ",".join(value) if value else ""
         return super(CharField, self).get_prep_value(value)
 
     def country_to_text(self, value):
@@ -348,7 +348,8 @@ class CountryField(CharField):
                 iter(value)
             except TypeError:
                 value = [value]
-        return list(filter(None, [self.country_to_text(c) for c in value]))
+        # Remove duplicates and False-y values, sort.
+        return sorted(set(filter(None, (self.country_to_text(c) for c in value))))
 
     def deconstruct(self):
         """
@@ -389,8 +390,7 @@ class CountryField(CharField):
         )
         if "coerce" not in kwargs:
             kwargs["coerce"] = super().to_python
-        field = super().formfield(**kwargs)
-        return field
+        return super().formfield(**kwargs)
 
     def to_python(self, value):
         if not self.multiple:
@@ -463,7 +463,7 @@ class ExactNameLookup(lookups.Exact):
         )
 
     def get_rhs_op(self, connection, rhs):
-        return connection.operators['exact'] % rhs
+        return connection.operators["exact"] % rhs
 
 
 @CountryField.register_lookup
