@@ -1,4 +1,5 @@
 from django.utils.translation import gettext_lazy as _
+
 from django_countries import Countries
 
 
@@ -7,8 +8,8 @@ class FantasyCountries(Countries):
 
 
 class TranslationFallbackCountries(Countries):
-    COMMON_NAMES = {"YE": "YYYemen"}
-    OLD_NAMES = {"NZ": [_("New Zealand")]}
+    COMMON_NAMES = {"NZ": _("Middle Earth")}
+    OLD_NAMES = {"NZ": [_("Middle Earth")]}
 
 
 class GBRegionCountries(Countries):
