@@ -1,4 +1,5 @@
 from django.db import models
+
 from django_countries.fields import CountryField
 from django_countries.tests import custom_countries
 
@@ -20,7 +21,7 @@ class Person(models.Model):
 
 
 class AllowNull(models.Model):
-    country = CountryField(null=True, blank_label="(select country)")
+    country = CountryField(null=True, blank=True, blank_label="(select country)")
 
 
 class MultiCountry(models.Model):
