@@ -1,13 +1,12 @@
 from django.test import TestCase, override_settings
+from rest_framework import serializers, views
+from rest_framework.test import APIRequestFactory
 
 from django_countries import countries
 from django_countries.fields import Country
-from django_countries.tests.models import Person, MultiCountry
-from django_countries.tests.custom_countries import FantasyCountries
 from django_countries.serializers import CountryFieldMixin
-
-from rest_framework.test import APIRequestFactory
-from rest_framework import serializers, views
+from django_countries.tests.custom_countries import FantasyCountries
+from django_countries.tests.models import MultiCountry, Person
 
 
 def countries_display(countries):
@@ -114,7 +113,7 @@ class TestDRF(TestCase):
     def test_multi_serialize(self):
         mc = MultiCountry(countries="NZ,AU")
         serializer = MultiCountrySerializer(mc)
-        self.assertEqual(serializer.data, {"countries": ["NZ", "AU"]})
+        self.assertEqual(serializer.data, {"countries": ["AU", "NZ"]})
 
     def test_multi_serialize_empty(self):
         mc = MultiCountry(countries="")
@@ -148,7 +147,7 @@ class TestDRF(TestCase):
         self.assertTrue(serializer.is_valid())
         saved = serializer.save()
         loaded = MultiCountry.objects.get(pk=saved.pk)
-        self.assertEqual(loaded.countries, [Country("NZ"), Country("AU")])
+        self.assertEqual(loaded.countries, [Country("AU"), Country("NZ")])
 
     def test_deserialize_blank_invalid(self):
         serializer = PersonSerializer(data={"name": "Chris", "country": ""})
