@@ -12,6 +12,7 @@ from django.forms.models import modelform_factory
 from django.test import TestCase, override_settings
 from django.utils import translation
 from django.utils.encoding import force_str
+
 from django_countries import countries, data, fields
 from django_countries.fields import CountryField
 from django_countries.tests import custom_countries, forms
@@ -19,7 +20,7 @@ from django_countries.tests.models import AllowNull, MultiCountry, Person, WithP
 
 
 # Django 3.2 introduced a db_collation attr on fields.
-def has_db_collation():
+def has_db_collation() -> bool:
     major, minor = django.VERSION[0:2]
     return (major > 3) or (major == 3 and minor >= 2)
 
@@ -128,7 +129,7 @@ class TestCountryField(TestCase):
 
             errors = checks.run_checks()
             self.assertEqual([e.id for e in errors], ["django_countries.E100"] * 2)
-            errors_dict = dict((e.obj, e) for e in errors)
+            errors_dict = {e.obj: e for e in errors}
             self.assertFalse(
                 "blank=True"
                 in errors_dict[MultiNullCountry._meta.get_field("countries")].hint
@@ -422,15 +423,24 @@ class TestCountryMultiple(TestCase):
         self.assertEqual(obj.countries[0], "AU")
         self.assertEqual(obj.countries[1], "NZ")
 
+    def test_multiple_with_duplicates(self):
+        obj = MultiCountry(countries="AU,NZ,AU")
+        for country in obj.countries:
+            self.assertTrue(isinstance(country, fields.Country))
+        self.assertEqual(obj.countries, ["AU", "NZ"])
+
+        obj = MultiCountry(countries="")
+        self.assertEqual(obj.countries, [])
+
     def test_set_text(self):
         obj = MultiCountry()
         obj.countries = "NZ,AU"
-        self.assertEqual(obj.countries, ["NZ", "AU"])
+        self.assertEqual(obj.countries, ["AU", "NZ"])
 
     def test_set_list(self):
         obj = MultiCountry()
         obj.countries = ["NZ", "AU"]
-        self.assertEqual(obj.countries, ["NZ", "AU"])
+        self.assertEqual(obj.countries, ["AU", "NZ"])
 
     def test_set_country(self):
         obj = MultiCountry()
@@ -440,10 +450,10 @@ class TestCountryMultiple(TestCase):
     def test_set_countries(self):
         obj = MultiCountry()
         obj.countries = [fields.Country("NZ"), fields.Country("AU")]
-        self.assertEqual(obj.countries, ["NZ", "AU"])
+        self.assertEqual(obj.countries, ["AU", "NZ"])
 
     def test_all_countries(self):
-        all_codes = list(c[0] for c in countries)
+        all_codes = sorted(c[0] for c in countries)
         MultiCountry.objects.create(countries=all_codes)
         obj = MultiCountry.objects.get()
         self.assertEqual(obj.countries, all_codes)
@@ -588,9 +598,14 @@ class TestModelForm(TestCase):
 
         form = forms.PersonForm()
         self.assertEqual(form.fields["country"].choices[0], blank)
+        html = str(form["country"]).split(">", 1)[0]
+        self.assertEqual(html, '<select name="country" required id="id_country"')
 
         multi_form = forms.MultiCountryForm()
         self.assertNotEqual(multi_form.fields["countries"].choices[0], blank)
+        html = str(multi_form["countries"]).split(">", 1)[0]
+        expected = '<select name="countries" required id="id_countries" multiple'
+        self.assertEqual(html, expected)
 
     def test_no_blank_choice(self):
         form = forms.PersonForm()
@@ -601,6 +616,8 @@ class TestModelForm(TestCase):
     def test_blank_choice_label(self):
         form = forms.AllowNullForm()
         self.assertEqual(form.fields["country"].choices[0], ("", "(select country)"))
+        html = str(form["country"]).split(">", 1)[0]
+        self.assertEqual(html, '<select name="country" id="id_country"')
 
     def test_validation(self):
         form = forms.MultiCountryForm(data={"countries": ["NZ", "AU"]})
@@ -656,4 +673,4 @@ class TestLoadData(TestCase):
         self.assertEqual(Person.objects.get().country, "NZ")
         countries = MultiCountry.objects.get().countries
         countries = [country.code for country in countries]
-        self.assertEqual(countries, ["NZ", "AU"])
+        self.assertEqual(countries, ["AU", "NZ"])
