@@ -1,4 +1,4 @@
-from django.template import Template, Context
+from django.template import Context, Template
 from django.test import TestCase
 from django.utils import translation
 
